pub enum ParseError<HeaderParseError: Error, PayloadParserError: Error> {
FileTooSmall,
Identifier(IdentifierParseError),
IoError(Arc<Error>),
Header(HeaderParseError),
Payload(PayloadParserError),
}Expand description
An error occurred parsing an SF3 file.
Variants
FileTooSmall
The file was smaller than expected, not enough data to parse.
Identifier(IdentifierParseError)
An error occurred parsing the file Identifier.
IoError(Arc<Error>)
The source could not be read due to an error.
Header(HeaderParseError)
An error occurred parsing the file Header.
Payload(PayloadParserError)
An error occurred parsing the file Payload.